@@ -12,12 +12,12 @@ def schema_(data):
     details=[]
     for col in data:
         schema[col]={
-            'min':flaot(round(data[col].min(),2)),
-            'max':flaot(round(data[col].max(),2)),
-            'std':flaot(round(data[col].std(),2)),
-            "variance":flaot(round(data[col].var(),2)),
-            "mean":flaot(round(data[col].mean(),2)),
-            "median":flaot(round(data[col].median(),2)),
+            'min':float(round(data[col].min(),2)),
+            'max':float(round(data[col].max(),2)),
+            'std':float(round(data[col].std(),2)),
+            "variance":float(round(data[col].var(),2)),
+            "mean":float(round(data[col].mean(),2)),
+            "median":float(round(data[col].median(),2)),
             "data type":str(data[col].dtype),
             "unique_values":int(len(data[col].unique())),
             "25th percentile":str(round(data[col].quantile(0.25),2)),
